@@ -17,8 +17,6 @@
 #include <cassert>
 #include <cstdlib>
 #include <sigc++/tuple-utils/tuple_for_each.h>
-#include <utility>
-//#include <typeinfo>
 #include <iostream>
 #include <functional>
 
